@@ -55,6 +55,14 @@ impl Canonicalizer {
                         span: span.clone(),
                     }));
                 }
+                AssigneeAccess::ArrayRange(start, stop) => {
+                    left = Box::new(Expression::ArrayRangeAccess(ArrayRangeAccessExpression {
+                        array: left,
+                        left: start.map(Box::new),
+                        right: stop.map(Box::new),
+                        span: span.clone(),
+                    }));
+                }
                 AssigneeAccess::Tuple(positive_number, _) => {
                     left = Box::new(Expression::TupleAccess(TupleAccessExpression {
                         tuple: left,
@@ -69,7 +77,6 @@ impl Canonicalizer {
                         span: span.clone(),
                     }));
                 }
-                _ => return Err(ReducerError::from(CombinerError::illegal_compound_array_range(&span))),
             }
         }
 
@@ -375,6 +382,7 @@ impl Canonicalizer {
                     variable: iteration.variable.clone(),
                     start,
                     stop,
+                    inclusive: iteration.inclusive,
                     block,
                     span: iteration.span.clone(),
                 })
@@ -384,23 +392,22 @@ impl Canonicalizer {
                     ConsoleFunction::Assert(expression) => {
                         ConsoleFunction::Assert(self.canonicalize_expression(expression))
                     }
-                    ConsoleFunction::Debug(format) | ConsoleFunction::Error(format) | ConsoleFunction::Log(format) => {
-                        let parameters = format
+                    ConsoleFunction::Error(args) | ConsoleFunction::Log(args) => {
+                        let parameters = args
                             .parameters
                             .iter()
                             .map(|parameter| self.canonicalize_expression(parameter))
                             .collect();
 
-                        let formatted = FormatString {
-                            parts: format.parts.clone(),
+                        let console_args = ConsoleArgs {
+                            string: args.string.clone(),
                             parameters,
-                            span: format.span.clone(),
+                            span: args.span.clone(),
                         };
 
                         match &console_function_call.function {
-                            ConsoleFunction::Debug(_) => ConsoleFunction::Debug(formatted),
-                            ConsoleFunction::Error(_) => ConsoleFunction::Error(formatted),
-                            ConsoleFunction::Log(_) => ConsoleFunction::Log(formatted),
+                            ConsoleFunction::Error(_) => ConsoleFunction::Error(console_args),
+                            ConsoleFunction::Log(_) => ConsoleFunction::Log(console_args),
                             _ => unimplemented!(), // impossible
                         }
                     }
@@ -486,6 +493,10 @@ impl ReconstructingReducer for Canonicalizer {
     }
 
     fn reduce_string(&mut self, string: &[Char], span: &Span) -> Result<Expression, ReducerError> {
+        if string.is_empty() {
+            return Err(ReducerError::empty_string(span));
+        }
+
         let mut elements = Vec::new();
         let mut col_adder = 0;
         for (index, character) in string.iter().enumerate() {
@@ -593,19 +604,13 @@ impl ReconstructingReducer for Canonicalizer {
         value: Expression,
     ) -> Result<AssignStatement, ReducerError> {
         match value {
-            Expression::Binary(binary_expr) if assign.operation == AssignOperation::Assign => Ok(AssignStatement {
-                operation: AssignOperation::Assign,
-                assignee,
-                value: Expression::Binary(binary_expr),
-                span: assign.span.clone(),
-            }),
-            Expression::Binary(binary_expr) if assign.operation != AssignOperation::Assign => {
+            value if assign.operation != AssignOperation::Assign => {
                 let left = self.canonicalize_accesses(
                     Expression::Identifier(assignee.identifier.clone()),
                     &assignee.accesses,
                     &assign.span,
                 )?;
-                let right = Box::new(Expression::Binary(binary_expr));
+                let right = Box::new(value);
                 let op = self.compound_operation_converstion(&assign.operation)?;
 
                 let new_value = Expression::Binary(BinaryExpression {
@@ -622,36 +627,12 @@ impl ReconstructingReducer for Canonicalizer {
                     span: assign.span.clone(),
                 })
             }
-            Expression::Value(value_expr) if assign.operation != AssignOperation::Assign => {
-                let left = self.canonicalize_accesses(
-                    Expression::Identifier(assignee.identifier.clone()),
-                    &assignee.accesses,
-                    &assign.span,
-                )?;
-                let right = Box::new(Expression::Value(value_expr));
-                let op = self.compound_operation_converstion(&assign.operation)?;
-
-                let new_value = Expression::Binary(BinaryExpression {
-                    left,
-                    right,
-                    op,
-                    span: assign.span.clone(),
-                });
-
-                Ok(AssignStatement {
-                    operation: AssignOperation::Assign,
-                    assignee,
-                    value: new_value,
-                    span: assign.span.clone(),
-                })
-            }
-            Expression::ArrayInline(_) => Ok(AssignStatement {
+            value => Ok(AssignStatement {
                 operation: AssignOperation::Assign,
                 assignee,
                 value,
                 span: assign.span.clone(),
             }),
-            _ => Ok(assign.clone()),
         }
     }
 
